@@ -71,13 +71,13 @@ def connect():
             print(response[ERROR])
 
     except requests.exceptions.HTTPError:
-        raise Exception("Http error occurred") from None
+        print("Http error occurred")
     except requests.exceptions.ConnectionError:
-        raise ConnectionError("Connection error occurred") from None
+        print("Connection error occurred")
     except requests.exceptions.Timeout:
-        raise TimeoutError("Request timed out...") from None
+        print("Request timed out...")
     except requests.exceptions.RequestException:
-        raise Exception("RequestException occurred") from None
+        print("RequestException occurred")
 
 
 class AthenaClient:
@@ -108,13 +108,13 @@ class AthenaClient:
                 return response[ERROR]
 
         except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
+            print("Http error occurred")
         except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
+            print("Connection error occurred")
         except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
+            print("Request timed out...")
         except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+            print("RequestException occurred")
 
     def tables(self, schema_name, result_as_df=True):
         """Returns all the tables present in a schema"""
@@ -135,13 +135,13 @@ class AthenaClient:
                 return response[ERROR]
 
         except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
+            print("Http error occurred")
         except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
+            print("Connection error occurred")
         except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
+            print("Request timed out...")
         except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+            print("RequestException occurred")
 
     def top(self, schema_name, table_name, limit=None, result_as_df=True):
         """Returns records from a table"""
@@ -164,13 +164,13 @@ class AthenaClient:
                 return response[ERROR]
 
         except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
+            print("Http error occurred")
         except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
+            print("Connection error occurred")
         except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
+            print("Request timed out...")
         except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+            print("RequestException occurred")
 
     def run_query(self, query_string, result_as_df=True):
         """Run a specified query"""
@@ -180,9 +180,9 @@ class AthenaClient:
             r = requests.post(self._ccf_services_host + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS,
                               cookies=dict(sessionId=self._access_token))
             response = r.json()
+            queries = list(filter(None, query_string.split(';')))
             if response[STATUS] == SUCCESS:
-                if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    queries = list(filter(None, query_string.split(';')))
+                if not result_as_df and isinstance(response[RESULT], (dict, list)):
                     if len(queries) > 1:
                         results = [pd.DataFrame.from_dict(item).style.set_caption(
                             f"""Query results for <i>\"{queries[i]};\"</i>""").hide_index().set_table_styles(TABLE_STYLES) for i, item in
@@ -194,27 +194,29 @@ class AthenaClient:
                             TABLE_STYLES)
                         return display(result)
                 else:
-                    results = [pd.DataFrame.from_dict(item) for item in response[RESULT]]
+                    if len(queries) > 1:
+                        results = [pd.DataFrame.from_dict(item) for item in response[RESULT]]
+                    else:
+                        results = pd.DataFrame.from_dict(response[RESULT])
                     return results
             else:
                 return response[ERROR]
 
         except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
+            print("Http error occurred")
         except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
+            print("Connection error occurred")
         except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
+            print("Request timed out...")
         except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+            print("RequestException occurred")
 
-    def save_data(self, data, file_name, s3_path):
+    def save_data(self, data, file_name, s3_bucket):
         """Returns records from a table"""
         try:
             d = data.to_dict(orient='records')
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "file_name": file_name,
-                                  "s3_bucket": s3_path, "data": d})
-            print(payload)
+                                  "s3_bucket": s3_bucket, "data": d})
             r = requests.post(self._ccf_services_host + API_SAVE_DATA_TO_S3, data=payload, headers=HEADERS,
                               cookies=dict(sessionId=self._access_token))
             response = r.json()
@@ -224,10 +226,10 @@ class AthenaClient:
                 return response[ERROR]
 
         except requests.exceptions.HTTPError:
-            raise Exception("Http error occurred") from None
+            print("Http error occurred")
         except requests.exceptions.ConnectionError:
-            raise ConnectionError("Connection error occurred") from None
+            print("Connection error occurred")
         except requests.exceptions.Timeout:
-            raise TimeoutError("Request timed out...") from None
+            print("Request timed out...")
         except requests.exceptions.RequestException:
-            raise Exception("RequestException occurred") from None
+            print("RequestException occurred")
